Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS SQL Workbench.

Actions, resources, and condition keys for AWS SQL Workbench - Service Authorization Reference

# Actions, resources, and condition keys for AWS SQL Workbench

AWS SQL Workbench (service prefix: `sqlworkbench` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by AWS SQL Workbench
- Resource types defined by AWS SQL Workbench
- Condition keys for AWS SQL Workbench

## Actions defined by AWS SQL Workbench

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

###### Note

Resource condition keys are listed in the Resource types table. You can find a link to the resource type that applies to an action in the Resource types (*required) column of the Actions table. The resource type in the Resource types table includes the Condition keys column, which are the resource condition keys that apply to an action in the Actions table.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
AssociateConnectionWithChart [permission only] | Grants permission to associate connection to a chart | Write | chart* |  |
connection* |  |
AssociateConnectionWithTab [permission only] | Grants permission to associate connection to a tab | Write | connection* |  |
AssociateNotebookWithTab [permission only] | Grants permission to associate notebook to a tab | Write | notebook* |  |
AssociateQueryWithTab [permission only] | Grants permission to associate query to a tab | Write | query* |  |
BatchDeleteFolder [permission only] | Grants permission to delete folders on your account | Write |  |  |
BatchGetNotebookCell [permission only] | Grants permission to get notebook cells content on your account | Read | notebook* |  |
CreateAccount [permission only] | Grants permission to create SQLWorkbench account | Write |  |  |
CreateChart [permission only] | Grants permission to create new saved chart on your account | Write | chart* |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
CreateConnection [permission only] | Grants permission to create a new connection on your account | Write | connection* |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
CreateFolder [permission only] | Grants permission to create folder on your account | Write |  |  |
CreateNotebook [permission only] | Grants permission to create a new notebook on your account | Write | notebook* |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
CreateNotebookCell [permission only] | Grants permission to create a notebook cell on your account | Write | notebook* |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
CreateNotebookFromVersion [permission only] | Grants permission to create a new notebook from a notebook version on your account | Write | notebook* |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
CreateNotebookVersion [permission only] | Grants permission to create a notebook version on your account | Write | notebook* |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
CreateSavedQuery [permission only] | Grants permission to create a new saved query on your account | Write | query* |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
DeleteChart [permission only] | Grants permission to remove charts on your account | Write | chart* |  |
DeleteConnection [permission only] | Grants permission to remove connections on your account | Write | connection* |  |
DeleteNotebook [permission only] | Grants permission to remove notebooks on your account | Write | notebook* |  |
DeleteNotebookCell [permission only] | Grants permission to remove notebooks cells on your account | Write | notebook* |  |
DeleteNotebookVersion [permission only] | Grants permission to remove notebooks cells on your account | Write | notebook* |  |
DeleteSavedQuery [permission only] | Grants permission to remove saved queries on your account | Write | query* |  |
DeleteTab [permission only] | Grants permission to remove a tab on your account | Write |  |  |
DriverExecute [permission only] | Grants permission to execute a query in your redshift cluster | Write | connection* |  |
DuplicateNotebook [permission only] | Grants permission to create a new notebook by duplicating an existing one on your account | Write | notebook* |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
ExportNotebook [permission only] | Grants permission to export a notebook on your account | Read | notebook* |  |
GenerateSession [permission only] | Grants permission to generate a new session on your account | Write |  |  |
GetAccountInfo [permission only] | Grants permission to get account info | Read |  |  |
GetAccountSettings [permission only] | Grants permission to get account settings | Read |  |  |
GetAutocompletionMetadata [permission only] | Grants permission to get database structure metadata for auto-completion | Read |  |  |
GetAutocompletionResource [permission only] | Grants permission to get database structure information for auto-completion | Read |  |  |
GetChart [permission only] | Grants permission to get charts on your account | Read | chart* |  |
GetConnection [permission only] | Grants permission to get connections on your account | Read | connection* |  |
GetNotebook [permission only] | Grants permission to get notebook metadata on your account | Read | notebook* |  |
GetNotebookVersion [permission only] | Grants permission to get the content of a notebook version on your account | Read | notebook* |  |
GetQSqlRecommendations [permission only] | Grants permission to get text to SQL recommendations | Read |  |  |
GetQueryExecutionHistory [permission only] | Grants permission to get the query execution history on your account | Read |  |  |
GetSavedQuery [permission only] | Grants permission to get saved query on your account | Read | query* |  |
GetSchemaInference [permission only] | Grants permission to get the columns and data types inferred from a file | Read |  |  |
GetUserInfo [permission only] | Grants permission to get user info | Read |  |  |
GetUserWorkspaceSettings [permission only] | Grants permission to get workspace settings on your account | Read |  |  |
ImportNotebook [permission only] | Grants permission to import a notebook on your account | Write | notebook* |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
ListConnections [permission only] | Grants permission to list the connections on your account | List |  |  |
ListDatabases [permission only] | Grants permission to list databases of your redshift cluster | List |  |  |
ListFiles [permission only] | Grants permission to list files and folders | List |  |  |
ListNotebookVersions [permission only] | Grants permission to get notebook versions metadata on your account | List | notebook* |  |
ListNotebooks [permission only] | Grants permission to list the notebooks on your account | List |  |  |
ListQueryExecutionHistory [permission only] | Grants permission to list the query execution history on your account | List |  |  |
ListRedshiftClusters [permission only] | Grants permission to list redshift clusters on your account | List |  |  |
ListSampleDatabases [permission only] | Grants permission to list sample databases | Read |  |  |
ListSavedQueryVersions [permission only] | Grants permission to list versions of saved query on your account | List | query* |  |
ListTabs [permission only] | Grants permission to list tabs on your account | List |  |  |
ListTaggedResources [permission only] | Grants permission to list tagged resources | Read |  |  |
ListTagsForResource [permission only] | Grants permission to list the tags of an sqlworkbench resource | Read | chart |  |
connection |  |
notebook |  |
query |  |
PutTab [permission only] | Grants permission to create or update a tab on your account | Write |  |  |
PutUserWorkspaceSettings [permission only] | Grants permission to update workspace settings on your account | Write |  |  |
RestoreNotebookVersion [permission only] | Grants permission to restore a notebook on your account to a version | Write | notebook* |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
TagResource [permission only] | Grants permission to tag an sqlworkbench resource | Tagging | chart |  |
connection |  |
notebook |  |
query |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
UntagResource [permission only] | Grants permission to untag an sqlworkbench resource | Tagging | chart |  |
connection |  |
notebook |  |
query |  |
| aws:TagKeys |
UpdateAccountConnectionSettings [permission only] | Grants permission to update account-wide connection settings | Write |  |  |
UpdateAccountExportSettings [permission only] | Grants permission to update account-wide export settings | Write |  |  |
UpdateAccountGeneralSettings [permission only] | Grants permission to update account-wide general settings | Write |  |  |
UpdateAccountQSqlSettings [permission only] | Grants permission to update account-wide text to SQL settings | Write |  |  |
UpdateChart [permission only] | Grants permission to update a chart on your account | Write | chart* |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
UpdateConnection [permission only] | Grants permission to update a connection on your account | Write | connection* |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
UpdateFileFolder [permission only] | Grants permission to move files on your account | Write | chart |  |
query |  |
UpdateFolder [permission only] | Grants permission to update a folder's name and details on your account | Write |  |  |
UpdateNotebook [permission only] | Grants permission to update a notebook metadata on your account | Write | notebook* |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
UpdateNotebookCellContent [permission only] | Grants permission to update a notebook cell content on your account | Write | notebook* |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
UpdateNotebookCellLayout [permission only] | Grants permission to update a notebook cell layout on your account | Write | notebook* |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
UpdateSavedQuery [permission only] | Grants permission to update a saved query on your account | Write | query* |  |
| aws:TagKeys aws:RequestTag/${TagKey} |

## Resource types defined by AWS SQL Workbench

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the Resource types table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
connection | `arn:$ { Partition}:sqlworkbench:$ { Region}:$ { Account}:connection/$ { ResourceId}` | aws:ResourceTag/${TagKey}
query | `arn:$ { Partition}:sqlworkbench:$ { Region}:$ { Account}:query/$ { ResourceId}` | aws:ResourceTag/${TagKey}
chart | `arn:$ { Partition}:sqlworkbench:$ { Region}:$ { Account}:chart/$ { ResourceId}` | aws:ResourceTag/${TagKey}
notebook | `arn:$ { Partition}:sqlworkbench:$ { Region}:$ { Account}:notebook/$ { ResourceId}` | aws:ResourceTag/${TagKey}

## Condition keys for AWS SQL Workbench

AWS SQL Workbench defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by the tags that are passed in the request | String
aws:ResourceTag/${TagKey} | Filters access by the tags that are associated with the resource | String
aws:TagKeys | Filters access by the tag keys that are passed in the request | ArrayOfString

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.